==> nrbc-1.3-sources.jar: org/example/dde/FindrequiredtruckResponse.java <==

package org.example.dde;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="truckfound" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "truckfound"
})
@XmlRootElement(name = "findrequiredtruckResponse")
public class FindrequiredtruckResponse {

    @XmlElement(required = true)
    protected String truckfound;

    /**
     * Gets the value of the truckfound property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTruckfound() {
        return truckfound;
    }

    /**
     * Sets the value of the truckfound property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTruckfound(String value) {
        this.truckfound = value;
    }

}

==> nrbc-1.4-sources.jar: org/example/dde/FindrequiredtruckResponse.java <==

package org.example.dde;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.builder.JAXBToStringBuilder;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="truckfound" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "truckfound"
})
@XmlRootElement(name = "findrequiredtruckResponse")
public class FindrequiredtruckResponse
    implements ToString
{

    @XmlElement(required = true)
    protected String truckfound;

    /**
     * Gets the value of the truckfound property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTruckfound() {
        return truckfound;
    }

    /**
     * Sets the value of the truckfound property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTruckfound(String value) {
        this.truckfound = value;
    }

    public void toString(ToStringBuilder toStringBuilder) {
        {
            String theTruckfound;
            theTruckfound = this.getTruckfound();
            toStringBuilder.append("truckfound", theTruckfound);
        }
    }

    public String toString() {
        final ToStringBuilder toStringBuilder = new JAXBToStringBuilder(this);
        toString(toStringBuilder);
        return toStringBuilder.toString();
    }

}
